# Generated by roxygen2: do not edit by hand

S3method(plot,adaptive_thresholds)
S3method(plot,lifting_scheme)
S3method(plot,lwt)
S3method(print,adaptive_thresholds)
S3method(print,lifting_scheme)
S3method(print,lwt)
S3method(print,wavelet_diagnosis)
S3method(print,wavelet_stream)
export(compute_adaptive_threshold)
export(custom_wavelet)
export(denoise_signal_causal)
export(denoise_signal_offline)
export(diagnose_wavelet)
export(ilwt)
export(lift_step)
export(lifting_scheme)
export(lwt)
export(new_wavelet_stream)
export(threshold)
export(threshold_hard)
export(threshold_scad)
export(threshold_semisoft)
export(threshold_soft)
export(tune_alpha_beta)
export(validate_compact_support)
export(validate_orthogonality)
export(validate_perfect_reconstruction)
export(validate_shift_sensitivity)
export(validate_vanishing_moments)
export(visualize_wavelet_basis)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,barplot)
importFrom(graphics,grid)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,title)
importFrom(stats,cor)
importFrom(stats,median)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,ts.plot)
importFrom(utils,head)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
useDynLib(rLifting, .registration = TRUE)
